@@ -52,6 +52,7 @@ def quick_notify(title, message='', url='http://localhost:5222', path='/', timeo
 
 def main():
     from optparse import OptionParser
+    import time
     parser = OptionParser()
     parser.add_option("-u", "--url", dest="url",
                       default='http://localhost:5222',
@@ -59,11 +60,30 @@ def main():
     parser.add_option("-q", "--quick", dest="quick",
                       action="store_true", default=False,
                       help="http host")
+    parser.add_option("-i", "--im", dest="im",
+                      action="store_true", default=False,
+                      help="only send on im")
+    parser.add_option("-m", "--minutes", dest="minutes",
+                      action="store", default="0",
+                      help="wait X minutes before sending")
+    parser.add_option("-s", "--seconds", dest="seconds",
+                      action="store", default="0",
+                      help="wait X seconds before sending")
     options, args = parser.parse_args()
+
+    if options.minutes:
+        time.sleep(int(options.minutes) * 60)
+    if options.seconds:
+        time.sleep(int(options.seconds))
+
     if options.quick:
         meth = quick_notify
     else:
         meth = notify
-    print meth(to_str(' '.join(args)), url=options.url.strip('/'))
+
+    print meth(to_str(' '.join(args)),
+               url=options.url.strip('/'),
+               path=options.im and '/gtalk' or '/'
+              )
 
 
